pespin has uploaded this change for review.
tun: Fix typo in log line and comment
Change-Id: I2f7ec968035193e00652dc27217f46e0719e56e8
---
M src/core/tun.c
1 file changed, 2 insertions(+), 2 deletions(-)
git pull ssh://gerrit.osmocom.org:29418/libosmocore refs/changes/53/42453/1
diff --git a/src/core/tun.c b/src/core/tun.c
index 537caf9..4e2a902 100644
--- a/src/core/tun.c
+++ b/src/core/tun.c
@@ -305,11 +305,11 @@
* iface with a given name above and attempting to retrieve its ifindex based
* on that name. Someone (ie udev) could have the iface renamed in
* between here. It's a pity that TUNSETIFF doesn't copy back to us the
* newly allocated ifinidex as it does with ifname)
*/
tundev->ifindex = if_nametoindex(tundev->dev_name);
if (tundev->ifindex == 0) {
- LOGTUN(tundev, LOGL_ERROR, "Unable to find ifinidex for dev %s\n",
+ LOGTUN(tundev, LOGL_ERROR, "Unable to find ifindex for dev %s\n",
tundev->dev_name);
rc = -ENODEV;
goto close_ret;
@@ -305,11 +305,11 @@
* on that name. Someone (ie udev) could have the iface renamed in
* between here. It's a pity that TUNSETIFF doesn't copy back to us the
- * newly allocated ifinidex as it does with ifname)
+ * newly allocated ifindex as it does with ifname)
*/
tundev->ifindex = if_nametoindex(tundev->dev_name);
To view, visit change 42453. To unsubscribe, or for help writing mail filters, visit settings.